# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class BiddingErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class BiddingError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> BiddingErrorEnum.BiddingError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[BiddingErrorEnum.BiddingError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, BiddingErrorEnum.BiddingError]]: ...
        UNSPECIFIED = typing___cast(BiddingErrorEnum.BiddingError, 0)
        UNKNOWN = typing___cast(BiddingErrorEnum.BiddingError, 1)
        BIDDING_STRATEGY_TRANSITION_NOT_ALLOWED = typing___cast(BiddingErrorEnum.BiddingError, 2)
        CANNOT_ATTACH_BIDDING_STRATEGY_TO_CAMPAIGN = typing___cast(BiddingErrorEnum.BiddingError, 7)
        INVALID_ANONYMOUS_BIDDING_STRATEGY_TYPE = typing___cast(BiddingErrorEnum.BiddingError, 10)
        INVALID_BIDDING_STRATEGY_TYPE = typing___cast(BiddingErrorEnum.BiddingError, 14)
        INVALID_BID = typing___cast(BiddingErrorEnum.BiddingError, 17)
        BIDDING_STRATEGY_NOT_AVAILABLE_FOR_ACCOUNT_TYPE = typing___cast(BiddingErrorEnum.BiddingError, 18)
        CONVERSION_TRACKING_NOT_ENABLED = typing___cast(BiddingErrorEnum.BiddingError, 19)
        NOT_ENOUGH_CONVERSIONS = typing___cast(BiddingErrorEnum.BiddingError, 20)
        CANNOT_CREATE_CAMPAIGN_WITH_BIDDING_STRATEGY = typing___cast(BiddingErrorEnum.BiddingError, 21)
        CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CAMPAIGN_LEVEL_POP_BIDDING_STRATEGY = typing___cast(BiddingErrorEnum.BiddingError, 23)
        BIDDING_STRATEGY_NOT_SUPPORTED_WITH_AD_SCHEDULE = typing___cast(BiddingErrorEnum.BiddingError, 24)
        PAY_PER_CONVERSION_NOT_AVAILABLE_FOR_CUSTOMER = typing___cast(BiddingErrorEnum.BiddingError, 25)
        PAY_PER_CONVERSION_NOT_ALLOWED_WITH_TARGET_CPA = typing___cast(BiddingErrorEnum.BiddingError, 26)
        BIDDING_STRATEGY_NOT_ALLOWED_FOR_SEARCH_ONLY_CAMPAIGNS = typing___cast(BiddingErrorEnum.BiddingError, 27)
        BIDDING_STRATEGY_NOT_SUPPORTED_IN_DRAFTS_OR_EXPERIMENTS = typing___cast(BiddingErrorEnum.BiddingError, 28)
        BIDDING_STRATEGY_TYPE_DOES_NOT_SUPPORT_PRODUCT_TYPE_ADGROUP_CRITERION = typing___cast(BiddingErrorEnum.BiddingError, 29)
        BID_TOO_SMALL = typing___cast(BiddingErrorEnum.BiddingError, 30)
        BID_TOO_BIG = typing___cast(BiddingErrorEnum.BiddingError, 31)
        BID_TOO_MANY_FRACTIONAL_DIGITS = typing___cast(BiddingErrorEnum.BiddingError, 32)
        INVALID_DOMAIN_NAME = typing___cast(BiddingErrorEnum.BiddingError, 33)
        NOT_COMPATIBLE_WITH_PAYMENT_MODE = typing___cast(BiddingErrorEnum.BiddingError, 34)
        NOT_COMPATIBLE_WITH_BUDGET_TYPE = typing___cast(BiddingErrorEnum.BiddingError, 35)
        NOT_COMPATIBLE_WITH_BIDDING_STRATEGY_TYPE = typing___cast(BiddingErrorEnum.BiddingError, 36)
    UNSPECIFIED = typing___cast(BiddingErrorEnum.BiddingError, 0)
    UNKNOWN = typing___cast(BiddingErrorEnum.BiddingError, 1)
    BIDDING_STRATEGY_TRANSITION_NOT_ALLOWED = typing___cast(BiddingErrorEnum.BiddingError, 2)
    CANNOT_ATTACH_BIDDING_STRATEGY_TO_CAMPAIGN = typing___cast(BiddingErrorEnum.BiddingError, 7)
    INVALID_ANONYMOUS_BIDDING_STRATEGY_TYPE = typing___cast(BiddingErrorEnum.BiddingError, 10)
    INVALID_BIDDING_STRATEGY_TYPE = typing___cast(BiddingErrorEnum.BiddingError, 14)
    INVALID_BID = typing___cast(BiddingErrorEnum.BiddingError, 17)
    BIDDING_STRATEGY_NOT_AVAILABLE_FOR_ACCOUNT_TYPE = typing___cast(BiddingErrorEnum.BiddingError, 18)
    CONVERSION_TRACKING_NOT_ENABLED = typing___cast(BiddingErrorEnum.BiddingError, 19)
    NOT_ENOUGH_CONVERSIONS = typing___cast(BiddingErrorEnum.BiddingError, 20)
    CANNOT_CREATE_CAMPAIGN_WITH_BIDDING_STRATEGY = typing___cast(BiddingErrorEnum.BiddingError, 21)
    CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CAMPAIGN_LEVEL_POP_BIDDING_STRATEGY = typing___cast(BiddingErrorEnum.BiddingError, 23)
    BIDDING_STRATEGY_NOT_SUPPORTED_WITH_AD_SCHEDULE = typing___cast(BiddingErrorEnum.BiddingError, 24)
    PAY_PER_CONVERSION_NOT_AVAILABLE_FOR_CUSTOMER = typing___cast(BiddingErrorEnum.BiddingError, 25)
    PAY_PER_CONVERSION_NOT_ALLOWED_WITH_TARGET_CPA = typing___cast(BiddingErrorEnum.BiddingError, 26)
    BIDDING_STRATEGY_NOT_ALLOWED_FOR_SEARCH_ONLY_CAMPAIGNS = typing___cast(BiddingErrorEnum.BiddingError, 27)
    BIDDING_STRATEGY_NOT_SUPPORTED_IN_DRAFTS_OR_EXPERIMENTS = typing___cast(BiddingErrorEnum.BiddingError, 28)
    BIDDING_STRATEGY_TYPE_DOES_NOT_SUPPORT_PRODUCT_TYPE_ADGROUP_CRITERION = typing___cast(BiddingErrorEnum.BiddingError, 29)
    BID_TOO_SMALL = typing___cast(BiddingErrorEnum.BiddingError, 30)
    BID_TOO_BIG = typing___cast(BiddingErrorEnum.BiddingError, 31)
    BID_TOO_MANY_FRACTIONAL_DIGITS = typing___cast(BiddingErrorEnum.BiddingError, 32)
    INVALID_DOMAIN_NAME = typing___cast(BiddingErrorEnum.BiddingError, 33)
    NOT_COMPATIBLE_WITH_PAYMENT_MODE = typing___cast(BiddingErrorEnum.BiddingError, 34)
    NOT_COMPATIBLE_WITH_BUDGET_TYPE = typing___cast(BiddingErrorEnum.BiddingError, 35)
    NOT_COMPATIBLE_WITH_BIDDING_STRATEGY_TYPE = typing___cast(BiddingErrorEnum.BiddingError, 36)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> BiddingErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class RecommendationErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class RecommendationError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> RecommendationErrorEnum.RecommendationError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[RecommendationErrorEnum.RecommendationError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, RecommendationErrorEnum.RecommendationError]]: ...
        UNSPECIFIED = typing___cast(RecommendationErrorEnum.RecommendationError, 0)
        UNKNOWN = typing___cast(RecommendationErrorEnum.RecommendationError, 1)
        BUDGET_AMOUNT_TOO_SMALL = typing___cast(RecommendationErrorEnum.RecommendationError, 2)
        BUDGET_AMOUNT_TOO_LARGE = typing___cast(RecommendationErrorEnum.RecommendationError, 3)
        INVALID_BUDGET_AMOUNT = typing___cast(RecommendationErrorEnum.RecommendationError, 4)
        POLICY_ERROR = typing___cast(RecommendationErrorEnum.RecommendationError, 5)
        INVALID_BID_AMOUNT = typing___cast(RecommendationErrorEnum.RecommendationError, 6)
        ADGROUP_KEYWORD_LIMIT = typing___cast(RecommendationErrorEnum.RecommendationError, 7)
        RECOMMENDATION_ALREADY_APPLIED = typing___cast(RecommendationErrorEnum.RecommendationError, 8)
        RECOMMENDATION_INVALIDATED = typing___cast(RecommendationErrorEnum.RecommendationError, 9)
        TOO_MANY_OPERATIONS = typing___cast(RecommendationErrorEnum.RecommendationError, 10)
        NO_OPERATIONS = typing___cast(RecommendationErrorEnum.RecommendationError, 11)
        DIFFERENT_TYPES_NOT_SUPPORTED = typing___cast(RecommendationErrorEnum.RecommendationError, 12)
        DUPLICATE_RESOURCE_NAME = typing___cast(RecommendationErrorEnum.RecommendationError, 13)
        RECOMMENDATION_ALREADY_DISMISSED = typing___cast(RecommendationErrorEnum.RecommendationError, 14)
        INVALID_APPLY_REQUEST = typing___cast(RecommendationErrorEnum.RecommendationError, 15)
    UNSPECIFIED = typing___cast(RecommendationErrorEnum.RecommendationError, 0)
    UNKNOWN = typing___cast(RecommendationErrorEnum.RecommendationError, 1)
    BUDGET_AMOUNT_TOO_SMALL = typing___cast(RecommendationErrorEnum.RecommendationError, 2)
    BUDGET_AMOUNT_TOO_LARGE = typing___cast(RecommendationErrorEnum.RecommendationError, 3)
    INVALID_BUDGET_AMOUNT = typing___cast(RecommendationErrorEnum.RecommendationError, 4)
    POLICY_ERROR = typing___cast(RecommendationErrorEnum.RecommendationError, 5)
    INVALID_BID_AMOUNT = typing___cast(RecommendationErrorEnum.RecommendationError, 6)
    ADGROUP_KEYWORD_LIMIT = typing___cast(RecommendationErrorEnum.RecommendationError, 7)
    RECOMMENDATION_ALREADY_APPLIED = typing___cast(RecommendationErrorEnum.RecommendationError, 8)
    RECOMMENDATION_INVALIDATED = typing___cast(RecommendationErrorEnum.RecommendationError, 9)
    TOO_MANY_OPERATIONS = typing___cast(RecommendationErrorEnum.RecommendationError, 10)
    NO_OPERATIONS = typing___cast(RecommendationErrorEnum.RecommendationError, 11)
    DIFFERENT_TYPES_NOT_SUPPORTED = typing___cast(RecommendationErrorEnum.RecommendationError, 12)
    DUPLICATE_RESOURCE_NAME = typing___cast(RecommendationErrorEnum.RecommendationError, 13)
    RECOMMENDATION_ALREADY_DISMISSED = typing___cast(RecommendationErrorEnum.RecommendationError, 14)
    INVALID_APPLY_REQUEST = typing___cast(RecommendationErrorEnum.RecommendationError, 15)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> RecommendationErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



import grpc  # type: ignore
from google.ads.google_ads.v1.services.transports.keyword_plan_idea_service_grpc_transport import KeywordPlanIdeaServiceGrpcTransport
from google.auth.credentials import Credentials  # type: ignore
from google.api_core.gapic_v1.client_info import ClientInfo  # type: ignore
from google.api_core.retry import Retry  # type: ignore
from typing import Optional, Dict, Any, List, Sequence, Tuple, Union, Callable, ClassVar, Text

from google.protobuf.wrappers_pb2 import StringValue

from google.ads.google_ads.v1.services.enums import KeywordPlanNetworkEnum

from google.ads.google_ads.v1.proto.services.keyword_plan_idea_service_pb2 import KeywordAndUrlSeed, KeywordSeed, \
    GenerateKeywordIdeaResponse
from typing_extensions import TypedDict


class StringValueDict(TypedDict):
    value: Text


class KeywordPlanIdeaServiceClient:
    SERVICE_ADDRESS: ClassVar[str] = ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args: Any, **kwargs: Any) -> KeywordPlanIdeaServiceClient: ...
    @classmethod
    def from_service_account_json(cls, filename: str, *args: Any, **kwargs: Any) -> KeywordPlanIdeaServiceClient: ...
    transport: Union[KeywordPlanIdeaServiceGrpcTransport, Callable[[Credentials, type], KeywordPlanIdeaServiceGrpcTransport]] = ...
    def __init__(self, transport: Optional[Union[KeywordPlanIdeaServiceGrpcTransport, Callable[[Credentials, type], KeywordPlanIdeaServiceGrpcTransport]]] = ..., channel: Optional[grpc.Channel] = ..., credentials: Optional[Credentials] = ..., client_config: Optional[Dict[Any, Any]] = ..., client_info: Optional[ClientInfo] = ...) -> None: ...
    def generate_keyword_ideas(self, customer_id: str, language: Union[StringValueDict, StringValue], geo_target_constants: List[Union[StringValueDict, StringValue]], keyword_plan_network: KeywordPlanNetworkEnum.KeywordPlanNetwork, keyword_and_url_seed: Optional[Union[Dict[Any, Any], KeywordAndUrlSeed]] = ..., keyword_seed: Optional[Any] = ..., url_seed: Optional[Union[Dict[Any, Any], KeywordSeed]] = ..., retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> GenerateKeywordIdeaResponse: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class ExtensionTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ExtensionType(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> ExtensionTypeEnum.ExtensionType: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[ExtensionTypeEnum.ExtensionType]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, ExtensionTypeEnum.ExtensionType]]: ...
        UNSPECIFIED = typing___cast(ExtensionTypeEnum.ExtensionType, 0)
        UNKNOWN = typing___cast(ExtensionTypeEnum.ExtensionType, 1)
        NONE = typing___cast(ExtensionTypeEnum.ExtensionType, 2)
        APP = typing___cast(ExtensionTypeEnum.ExtensionType, 3)
        CALL = typing___cast(ExtensionTypeEnum.ExtensionType, 4)
        CALLOUT = typing___cast(ExtensionTypeEnum.ExtensionType, 5)
        MESSAGE = typing___cast(ExtensionTypeEnum.ExtensionType, 6)
        PRICE = typing___cast(ExtensionTypeEnum.ExtensionType, 7)
        PROMOTION = typing___cast(ExtensionTypeEnum.ExtensionType, 8)
        REVIEW = typing___cast(ExtensionTypeEnum.ExtensionType, 9)
        SITELINK = typing___cast(ExtensionTypeEnum.ExtensionType, 10)
        STRUCTURED_SNIPPET = typing___cast(ExtensionTypeEnum.ExtensionType, 11)
        LOCATION = typing___cast(ExtensionTypeEnum.ExtensionType, 12)
        AFFILIATE_LOCATION = typing___cast(ExtensionTypeEnum.ExtensionType, 13)
    UNSPECIFIED = typing___cast(ExtensionTypeEnum.ExtensionType, 0)
    UNKNOWN = typing___cast(ExtensionTypeEnum.ExtensionType, 1)
    NONE = typing___cast(ExtensionTypeEnum.ExtensionType, 2)
    APP = typing___cast(ExtensionTypeEnum.ExtensionType, 3)
    CALL = typing___cast(ExtensionTypeEnum.ExtensionType, 4)
    CALLOUT = typing___cast(ExtensionTypeEnum.ExtensionType, 5)
    MESSAGE = typing___cast(ExtensionTypeEnum.ExtensionType, 6)
    PRICE = typing___cast(ExtensionTypeEnum.ExtensionType, 7)
    PROMOTION = typing___cast(ExtensionTypeEnum.ExtensionType, 8)
    REVIEW = typing___cast(ExtensionTypeEnum.ExtensionType, 9)
    SITELINK = typing___cast(ExtensionTypeEnum.ExtensionType, 10)
    STRUCTURED_SNIPPET = typing___cast(ExtensionTypeEnum.ExtensionType, 11)
    LOCATION = typing___cast(ExtensionTypeEnum.ExtensionType, 12)
    AFFILIATE_LOCATION = typing___cast(ExtensionTypeEnum.ExtensionType, 13)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ExtensionTypeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class PromotionExtensionOccasionEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class PromotionExtensionOccasion(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> PromotionExtensionOccasionEnum.PromotionExtensionOccasion: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[PromotionExtensionOccasionEnum.PromotionExtensionOccasion]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, PromotionExtensionOccasionEnum.PromotionExtensionOccasion]]: ...
        UNSPECIFIED = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 0)
        UNKNOWN = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 1)
        NEW_YEARS = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 2)
        CHINESE_NEW_YEAR = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 3)
        VALENTINES_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 4)
        EASTER = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 5)
        MOTHERS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 6)
        FATHERS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 7)
        LABOR_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 8)
        BACK_TO_SCHOOL = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 9)
        HALLOWEEN = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 10)
        BLACK_FRIDAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 11)
        CYBER_MONDAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 12)
        CHRISTMAS = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 13)
        BOXING_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 14)
        INDEPENDENCE_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 15)
        NATIONAL_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 16)
        END_OF_SEASON = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 17)
        WINTER_SALE = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 18)
        SUMMER_SALE = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 19)
        FALL_SALE = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 20)
        SPRING_SALE = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 21)
        RAMADAN = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 22)
        EID_AL_FITR = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 23)
        EID_AL_ADHA = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 24)
        SINGLES_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 25)
        WOMENS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 26)
        HOLI = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 27)
        PARENTS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 28)
        ST_NICHOLAS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 29)
        CARNIVAL = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 30)
        EPIPHANY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 31)
        ROSH_HASHANAH = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 32)
        PASSOVER = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 33)
        HANUKKAH = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 34)
        DIWALI = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 35)
        NAVRATRI = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 36)
        SONGKRAN = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 37)
        YEAR_END_GIFT = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 38)
    UNSPECIFIED = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 0)
    UNKNOWN = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 1)
    NEW_YEARS = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 2)
    CHINESE_NEW_YEAR = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 3)
    VALENTINES_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 4)
    EASTER = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 5)
    MOTHERS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 6)
    FATHERS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 7)
    LABOR_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 8)
    BACK_TO_SCHOOL = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 9)
    HALLOWEEN = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 10)
    BLACK_FRIDAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 11)
    CYBER_MONDAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 12)
    CHRISTMAS = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 13)
    BOXING_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 14)
    INDEPENDENCE_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 15)
    NATIONAL_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 16)
    END_OF_SEASON = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 17)
    WINTER_SALE = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 18)
    SUMMER_SALE = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 19)
    FALL_SALE = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 20)
    SPRING_SALE = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 21)
    RAMADAN = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 22)
    EID_AL_FITR = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 23)
    EID_AL_ADHA = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 24)
    SINGLES_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 25)
    WOMENS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 26)
    HOLI = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 27)
    PARENTS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 28)
    ST_NICHOLAS_DAY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 29)
    CARNIVAL = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 30)
    EPIPHANY = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 31)
    ROSH_HASHANAH = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 32)
    PASSOVER = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 33)
    HANUKKAH = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 34)
    DIWALI = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 35)
    NAVRATRI = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 36)
    SONGKRAN = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 37)
    YEAR_END_GIFT = typing___cast(PromotionExtensionOccasionEnum.PromotionExtensionOccasion, 38)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PromotionExtensionOccasionEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class LabelErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class LabelError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> LabelErrorEnum.LabelError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[LabelErrorEnum.LabelError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, LabelErrorEnum.LabelError]]: ...
        UNSPECIFIED = typing___cast(LabelErrorEnum.LabelError, 0)
        UNKNOWN = typing___cast(LabelErrorEnum.LabelError, 1)
        CANNOT_APPLY_INACTIVE_LABEL = typing___cast(LabelErrorEnum.LabelError, 2)
        CANNOT_APPLY_LABEL_TO_DISABLED_AD_GROUP_CRITERION = typing___cast(LabelErrorEnum.LabelError, 3)
        CANNOT_APPLY_LABEL_TO_NEGATIVE_AD_GROUP_CRITERION = typing___cast(LabelErrorEnum.LabelError, 4)
        EXCEEDED_LABEL_LIMIT_PER_TYPE = typing___cast(LabelErrorEnum.LabelError, 5)
        INVALID_RESOURCE_FOR_MANAGER_LABEL = typing___cast(LabelErrorEnum.LabelError, 6)
        DUPLICATE_NAME = typing___cast(LabelErrorEnum.LabelError, 7)
        INVALID_LABEL_NAME = typing___cast(LabelErrorEnum.LabelError, 8)
        CANNOT_ATTACH_LABEL_TO_DRAFT = typing___cast(LabelErrorEnum.LabelError, 9)
        CANNOT_ATTACH_NON_MANAGER_LABEL_TO_CUSTOMER = typing___cast(LabelErrorEnum.LabelError, 10)
    UNSPECIFIED = typing___cast(LabelErrorEnum.LabelError, 0)
    UNKNOWN = typing___cast(LabelErrorEnum.LabelError, 1)
    CANNOT_APPLY_INACTIVE_LABEL = typing___cast(LabelErrorEnum.LabelError, 2)
    CANNOT_APPLY_LABEL_TO_DISABLED_AD_GROUP_CRITERION = typing___cast(LabelErrorEnum.LabelError, 3)
    CANNOT_APPLY_LABEL_TO_NEGATIVE_AD_GROUP_CRITERION = typing___cast(LabelErrorEnum.LabelError, 4)
    EXCEEDED_LABEL_LIMIT_PER_TYPE = typing___cast(LabelErrorEnum.LabelError, 5)
    INVALID_RESOURCE_FOR_MANAGER_LABEL = typing___cast(LabelErrorEnum.LabelError, 6)
    DUPLICATE_NAME = typing___cast(LabelErrorEnum.LabelError, 7)
    INVALID_LABEL_NAME = typing___cast(LabelErrorEnum.LabelError, 8)
    CANNOT_ATTACH_LABEL_TO_DRAFT = typing___cast(LabelErrorEnum.LabelError, 9)
    CANNOT_ATTACH_NON_MANAGER_LABEL_TO_CUSTOMER = typing___cast(LabelErrorEnum.LabelError, 10)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> LabelErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
